==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificate.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property file Local file certificate.
 * @property sds A [Secret Discovery Service](https://www.envoyproxy.io/docs/envoy/latest/configuration/security/secret#secret-discovery-service-sds) certificate.
 */
public data class VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificate(
    public val `file`: VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificateFile? = null,
    public val sds: VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificateSds? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificate):
            VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificate =
            VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificate(
                `file` = javaType.`file`().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificateFile.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificateSds.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificate.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property file Local file certificate.
 * @property sds A [Secret Discovery Service](https://www.envoyproxy.io/docs/envoy/latest/configuration/security/secret#secret-discovery-service-sds) certificate.
 */
public data class VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificate(
    public val `file`: VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificateFile? = null,
    public val sds: VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificateSds? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificate): VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificate =
            VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificate(
                `file` = javaType.`file`().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificateFile.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsCertificateSds.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
